BBC News - Home
Description: Visit BBC News for up-to-the-minute news, breaking news, video, audio and feature stories. BBC News provides trusted World and UK news as well as local and regional perspectives. Also entertainment, business, science, technology and health news.

## Accessibility links

- Skip to content
- Skip to local navigation
- Accessibility Help

## BBC iD

BBC iD

# 27 August 2014 Last updated at 03:23

RSS feed

## Fresh quit call over sex abuse report

The Police and Crime Commissioner for South Yorkshire faces calls to resign in light of the damning report into child abuse in Rotherham.

- '1,400 children abused' in Rotherham
- Rotherham abuse scandal at a glance
- The history of a child abuse scandal

## Ukraine and Russia hold direct talks

The Ukrainian and Russian presidents hold their first direct talks on the crisis in eastern Ukraine, but there appears to be no breakthrough.

- 'Little optimism' for talks Watch
- Russian aid or Trojan Horse?
- Key players in east Ukraine
- In maps: How crisis spread

## Primary school places budget squeeze

There are warnings that the rising primary school population in England is putting pressure on budgets and raising concerns of "supersize" schools.

- Super-size schools in population surge
- Primary places revealed amid squeeze
- Primaries to rise to 1,000 pupils

## Other Top Stories

- ### Boys 'overlooked' as abuse victims

  A report from children's charity Barnardo's says up to a third of victims of child sexual exploitation are male, much higher than previously thought.

- ### Overseas nurses 'face shorter tests'

  New rules mean nurses and midwives who have completed their training outside Europe will face shorter tests to check they are fit to work in the UK.

- ### Anti-independence firms make case

- ### American 'fighter' dies in Syria battle

- ### Farage to fight Thanet seat for UKIP

- ### Long-term Gaza ceasefire agreed

- ### Hollande names new French cabinet

- ### Hormone 'protects premature babies'

- ### Fans delight at Kate Bush comeback

## Video

- How much oil does Scotland have? Watch02:52
- Nigel Farage takes on South Thanet Watch04:22
- Highlights from MTV video awards Watch03:19
- How sheepdogs control unruly flocks Watch02:49
- Enduring appeal of India's Ambassador Watch02:45
- Keeping the disruptive in education Watch02:17
- Mexico tries to tame 'Beast' train Watch02:21
- Football club re-enacts 1917 match Watch01:39

## The Papers

- ### 'Horrific betrayal' - abuse scandal on front pages

  Findings that at least 1,400 children were subjected to appalling sexual exploitation in Rotherham between 1997 and 2013 lead most papers.

## Also in the News

- ### A sheepdog's 'two rules' for success

- ### Churchill 'rejected' WW1 help plea

## Sport

- ### Milton Keynes Dons 4-0 Manchester United

  Manchester United suffer a humiliating League Cup exit to MK Dons after a comprehensive defeat at the League One side.

- ### Man Utd sign Di Maria for Â£59.7m

- ### Root backs Cook for World Cup

- ### Celtic 0-1 NK Maribor

- ### Watson loses to Cirstea in US Open

## Business

- RBS to get Â£15m mortgage advice fine
- Malaysia Airlines job cuts a concern Watch

## Politics

- Boris Johnson confirms target seat
- Close-up look at referendum issues Watch

## Health

- UK Ebola patient gets test drug
- Cellist: 'Alcohol was my medicine' Watch

## Education

- US schools to have non-white majority
- 'Trojan horse' principal goes back to school Watch

## Technology

- Prison data loss leads to large fine
- How pedal power charges your phone Watch

## Sci/Environment

- New concerns over Iceland volcano
- How sheepdogs control unruly flocks Watch

## Entertainment

- Sherlock in triple Emmy Awards win
- Arrest warrant for Miley's MTV date Watch

## Magazine

- The drunken monkey that smashed up a bar
- Politicians and their shipping containers

## UK & Local News

### England

- 'Orders given' on Hillsborough notes
- Cyclists threat to London guide dogs

### Scotland

- Swinney says 'No currency, no debt'
- Golf club expenses from 1616 found

### Northern Ireland

- Police probe 'hate speech' claims
- Pensioner killed in road accident

### Wales

- 'Sex in custody officer' cleared
- Drink-related crime down in hotspot

### Local News

### Weather

## World News

### Africa

UN helicopter crashes in South Sudan

### Asia

Mumbai attack Jewish centre reopens

### Europe

Berlin's embattled mayor to quit

### Latin America

'Sex abuse' priest may be extradited

### Middle East

Deadly bombing hits Baghdad district

### US & Canada

Fight for leg room diverts flight

## In Pictures

- Day in pictures
- Lauren Bacall
- Maliki years
- Robin Williams
- Day in pictures
- Framing Hope
- Exodus of Yazidis
- Day in pictures

## Democracy Live

- ### House of Commons Watch

  Israel's response to rocket attacks must be "proportionate", insists a minister.

## Find a representative

Search terms Enter the name of who you are looking for, a place or full postcode e.g. CF10 3NQ

### BBC World Service

#### News and analysis in 27 languages

- Arabic Ø¹Ø±Ø¨Ù
- Chinese 中文

##### Languages continued (2 of 4)

- Persian فارسی
- Portuguese Brasil

##### Languages continued (3 of 4)

- Russian Русский
- Spanish Mundo

##### Languages continued (4 of 4)

- Urdu اردو
- Vietnamese Tiếng Việt

## Watch/Listen

- Kate Bush fans: 'It was worth the wait' Watch02:07
- What goes into a fake cigarette? Watch01:36
- Stars review Kate Bush's comeback Watch03:54
- Key moments from this year's Emmys Watch01:31
- Huge cheers for Kate Bush comeback Watch02:27
- Leaders face off for Scotland debate Watch02:59
- Ebola doctor's traumatic experiences Watch01:20
- Meet fighters taking on IS without US Watch02:29

- ### BBC News Channel Live

- ### BBC Radio 5 Live Live

## Features

- ### The knee problem

  When is it acceptable to recline your seat on flights?

- ### Character amnesia

  When China's children forget how to write

- ### Craft music

  The Italian city that as been making violins for centuries

- ### Mint condition

  Why is the Scotland referendum debate so focused on the pound?

- ### Righteous rehab

  Guatemala's religious centres that hunt and lock up drug addicts

- ### First in sport Watch

  Memories of the inaugural Special Olympics held in Chicago

- ### Record breakers

  How British football's record transfer fee has soared BBC Sport

## Analysis

- ### New dream team?

  Women are now frontrunners in tense EU jobs race

- ### Prevent policy

  UK's Prevent strategy remains deeply controversial

## Most Popular

### Shared

1. 1: '1,400 children abused' in Rotherham
2. 2: How Norway avoided the 'curse of oil'
3. 3: Hamas says truce agreed with Israel
4. 4: 'Ban E-cig use indoors,' says WHO
5. 5: Russians in Ukraine 'by accident'

### Read

1. 1: Fresh quit call over sex abuse report
2. 2: The etiquette of reclining seats on flights
3. 3: When Chinese children forget how to write
4. 4: American 'fighter' dies in Syria battle
5. 5: Fans delight at Kate Bush comeback
6. 6: The evolution of the 9/11 conspiracy theories
7. 7: 'Ban E-cig use indoors,' says WHO
8. 8: Simon Cowell: Why I sacked Cheryl
9. 9: Fight for leg room diverts flight
10. 10: Woman kills leopard in long battle

### Video/Audio

1. 1: The trouble with France - in 60 secs Watch
2. 3: Kate Bush fans: 'Worth the wait' Watch
3. 4: Sheep found with 20kg woolly coat Watch
4. 5: Chinese calligraphy: Thing of the past? Watch
5. 6: Women refugees break rules to survive Watch
6. 7: Giant sinkhole 'could keep growing' Watch
7. 8: Arrest warrant for Miley's MTV date Watch
8. 9: How much oil does Scotland have? Watch
9. 10: Long-term Gaza ceasefire agreed Watch

## Elsewhere on the BBC

- ### Dino-flaw

  Why movie dinosaurs are nothing like the real thing

## Market Data

Last Updated at 02:27 GMT

Market index | Current value | Trend | Variation | % variation
--- | --- | --- | --- | ---
Dow Jones | 17106.70 | Up | 29.83 | 0.17%
Nasdaq | 4570.64 | Up | 13.29 | 0.29%
FTSE 100 | 6822.76 | Up | 47.51 | 0.70%
Dax | 9588.15 | Up | 78.01 | 0.82%
Cac 40 | 4393.41 | Up | 51.30 | 1.18%
BBC Global 30 | 7381.90 | Up | 8.01 | 0.11%

## Programmes

BBC iPlayer

- #### Today Listen

  Morning news and current affairs. Includes Sports Desk; Weather; Thought for the Day.

- #### World at One Listen

  National and international news with Edward Stourton.

- #### Click Watch

  Click travels to Philadelphia to meet Evan Blass. Plus what does the internet sounds like?

## BBC links

- - Mobile site
  - Terms of Use
  - About the BBC
- - Privacy
  - Accessibility Help
- - Cookies
  - Contact the BBC
- - Parental Guidance

BBC © 2014 The BBC is not responsible for the content of external sites. Read more.

This page is best viewed in an up-to-date web browser with style sheets (CSS) enabled. While you will be able to view the content of this page in your current browser, you will not be able to get the full visual experience. Please consider upgrading your browser software or enabling style sheets (CSS) if you are able to do so.